@@ -137,6 +137,10 @@ tunein.com (L<StreamFinder::Tunein>), vimeo.com (L<StreamFinder::Vimeo>),
 and (youtube.com, et. al and other sites that youtube-dl supports) 
 (L<StreamFinder::Youtube>).  
 
+NOTE:  StreamFinder::Reciva will likely be removed next release after 
+January 30, 2021 due to that site's announcement that they're going 
+offline after that date!
+
 NOTE:  Facebook (Streamfinder::Facebook) has been removed because 
 logging into Facebook via the call to youtube-dl is now interpreted by 
 Facebook as a "rogue app. login" and will cause them to LOCK your account 
@@ -407,7 +411,7 @@ use strict;
 use warnings;
 use vars qw(@ISA @EXPORT $VERSION);
 
-our $VERSION = '1.37';
+our $VERSION = '1.38';
 our $DEBUG = 0;
 
 require Exporter;
